# -*- coding: utf-8 -*-
# This file is part of the diagram-module from m-ds for Tryton.
# The COPYRIGHT file at the top level of this repository contains the
# full copyright notices and license terms.

from trytond.wizard import Wizard, StateAction
from trytond.transaction import Transaction
from trytond.pool import Pool
from trytond.i18n import gettext
from trytond.pyson import PYSONEncoder


class OpenChartWizard(Wizard):
    'Open Chart'
    __name__ = 'diagram.wizchart'

    start_state = 'open_'
    open_ = StateAction('diagram.act_point_view')

    def do_open_(self, action):
        """ open view from doubleclick
        """
        Chart = Pool().get('diagram.chart')
        context = Transaction().context

        # add info to enable replace of ui-view
        chart, = Chart.browse([context['active_id']])
        if chart.ui_view_point:
            action['limit'] = len(chart.lines)
            action['pyson_context'] = PYSONEncoder().encode({
                'active_chart': chart.id,
                'chart': chart.id,
                })
            action['name'] = gettext(
                'diagram.msg_name_graph',
                gname=chart.rec_name)
        return action, {}

# end OpenChartWizard
