# -*- coding: utf-8 -*-
# This file is part of the diagram-module from m-ds for Tryton.
# The COPYRIGHT file at the top level of this repository contains the
# full copyright notices and license terms.

from trytond.pool import PoolMeta, Pool
from trytond.model import fields
from sql.conditionals import Case, Coalesce
from sql.aggregate import Sum


class Currency(metaclass=PoolMeta):
    __name__ = 'currency.currency'

    has_rates = fields.Function(fields.Boolean(
        string='Has Rates', readonly=True),
        'on_change_with_has_rates', searcher='search_has_rates')

    @fields.depends('rates')
    def on_change_with_has_rates(self, name=None):
        """ get True if currency has exchange rates
        """
        if self.rates is not None:
            if len(self.rates) > 0:
                return True
        return False

    @classmethod
    def search_has_rates(cls, names, clause):
        """ search in 'has_rates'
        """
        pool = Pool()
        Currency = pool.get('currency.currency')
        Rate = pool.get('currency.currency.rate')
        tab_cur = Currency.__table__()
        tab_rate = Rate.__table__()
        Operator = fields.SQL_OPERATORS[clause[1]]

        query = tab_cur.join(
                tab_rate,
                condition=tab_cur.id == tab_rate.currency,
                type_='LEFT OUTER',
            ).select(
                tab_cur.id,
                having=Operator(
                    Case(
                        (Sum(Coalesce(tab_rate.id, 0)) > 0, True),
                        else_=False),
                    clause[2]),
                group_by=[tab_cur.id])
        return [('id', 'in', query)]

# end Currency
