# -*- coding: utf-8 -*-
# This file is part of the diagram-module from m-ds for Tryton.
# The COPYRIGHT file at the top level of this repository contains the
# full copyright notices and license terms.

from trytond.model import ModelView, fields
from trytond.transaction import Transaction
from trytond.pool import Pool
from datetime import timedelta


class GraphContext(ModelView):
    'Graph Context'
    __name__ = 'diagram.point.context'

    chart = fields.Many2One(
        string='Chart', readonly=True,
        model_name='diagram.chart',
        states={'invisible': True})
    point_date = fields.Date(
        string='Date from',
        help='Start date of data presentation. ' +
        'Clear the date to switch to the current date.')
    date_to = fields.Function(fields.Date(
        string='to', readonly=True), 'on_change_with_date_to')

    @fields.depends('chart')
    def on_change_with_date_to(self, name=None):
        """ get end-date
        """
        if self.chart:
            return self.chart.used_end_date()

    @fields.depends('point_date', 'chart', '_parent_chart.numdays', 'date_to')
    def on_change_point_date(self):
        """ update end-date
        """
        GraphCtx = Pool().get('diagram.point.context')

        if self.point_date is None:
            self.point_date = GraphCtx.default_point_date()
        self.point_date = GraphCtx.limit_start_date(self.point_date)
        if self.chart:
            self.date_to = self.point_date + \
                timedelta(days=int(self.chart.numdays))

    @classmethod
    def limit_start_date(cls, start_date):
        """ set/limit start-date
        """
        Chart = Pool().get('diagram.chart')
        context = Transaction().context

        charts = Chart.search([('id', '=', context.get('chart', -1))])
        if charts:
            if start_date is None:
                start_date = charts[0].used_start_date()
            start_date = charts[0].limit_start_date(start_date)
        return start_date

    @classmethod
    def default_point_date(cls):
        """ start-date from context or chart
        """
        context = Transaction().context

        start_date = context.get('point_date', None)
        return cls.limit_start_date(start_date)

    @classmethod
    def default_chart(cls):
        """ get default from context
        """
        context = Transaction().context
        return context.get('chart', None)

# end GraphContext
